@@ -13,8 +13,8 @@
 *
 *  You should have received a copy of the GNU General Public License
 *  along with with program; see the file COPYING. If not, write to the
-*  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-*  MA  02111-1307  USA
+*  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+*  MA  02110-1301  USA
 */
 
 /**
@@ -25,6 +25,7 @@
 
 #include <stdio.h>
 #include <math.h>
+
 #include <lal/LALStdlib.h>
 #include <lal/LALConstants.h>
 #include <lal/AVFactories.h>
@@ -32,7 +33,6 @@
 #include <lal/LALFrStream.h>
 #include <lal/Units.h>
 #include <lal/BandPassTimeSeries.h>
-#include <lal/LALFrameL.h>
 
 #define TRUE       1
 #define FALSE      0
