@@ -13,8 +13,8 @@
 *
 *  You should have received a copy of the GNU General Public License
 *  along with with program; see the file COPYING. If not, write to the
-*  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-*  MA  02111-1307  USA
+*  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+*  MA  02110-1301  USA
 */
 
 /*----------------------------------------------------------------------- 
@@ -33,19 +33,17 @@
 
 #include <math.h>
 #include <ctype.h>
-#include <assert.h>
 #include <string.h>
 #include <time.h>
-#include <lalapps.h>
 #include <lal/LALStdio.h>
 #include <lal/LALgetopt.h>
 #include <lal/LALStdlib.h>
 #include <lal/LALConstants.h>
+#include <lal/LIGOLwXML.h>
 #include <lal/LIGOMetadataTables.h>
 #include <lal/LIGOMetadataUtils.h>
 #include <lal/LIGOMetadataInspiralUtils.h>
 #include <lal/LIGOMetadataRingdownUtils.h>
-#include <lal/LIGOLwXMLlegacy.h>
 #include <lal/Units.h>
 #include <lal/Date.h>
 #include <lal/InspiralInjectionParams.h>
@@ -419,7 +417,7 @@ static REAL4TimeSeries *injectWaveform(
 
 int main( int argc, char *argv[] )
 {
-  LALStatus             status = blank_status;
+  LALStatus             XLAL_INIT_DECL(status);
   LIGOTimeGPS           gpsStartTime = {0, 0};
   LIGOTimeGPS           earliestEndTime = {0, 0};
   ResponseFunction      injectionResponse = noResponse;
@@ -440,14 +438,14 @@ int main( int argc, char *argv[] )
 
   /* xml output data */
   CHAR                  fname[FILENAME_MAX];
-  MetadataTable         proctable;
-  MetadataTable         procparams;
-  MetadataTable         inspInjections;
-  MetadataTable         ringInjections;
+  ProcessTable         *proctable;
+  ProcessParamsTable   *procparams;
+  SimInspiralTable     *inspInjections;
+  SimRingdownTable     *ringInjections;
   ProcessParamsTable   *this_proc_param;
   SimInspiralTable     *inj  = NULL;
   SimRingdownTable     *ringList = NULL;
-  LIGOLwXMLStream       xmlfp;
+  LIGOLwXMLStream      *xmlfp;
   FILE                 *fp = NULL;
 
   /* LALgetopt arguments */
@@ -499,13 +497,13 @@ int main( int argc, char *argv[] )
 
 
   /* create the process and process params tables */
-  proctable.processTable = (ProcessTable *) 
+  proctable = (ProcessTable *)
     calloc( 1, sizeof(ProcessTable) );
-  XLALGPSTimeNow(&(proctable.processTable->start_time));
-  XLALPopulateProcessTable(proctable.processTable, PROGRAM_NAME, lalAppsVCSIdentInfo.vcsId,
+  XLALGPSTimeNow(&(proctable->start_time));
+  XLALPopulateProcessTable(proctable, PROGRAM_NAME, lalAppsVCSIdentInfo.vcsId,
       lalAppsVCSIdentInfo.vcsStatus, lalAppsVCSIdentInfo.vcsDate, 0);
-  snprintf( proctable.processTable->comment, LIGOMETA_COMMENT_MAX, " " );
-  this_proc_param = procparams.processParamsTable = (ProcessParamsTable *) 
+  snprintf( proctable->comment, LIGOMETA_COMMENT_MAX, " " );
+  this_proc_param = procparams = (ProcessParamsTable *)
     calloc( 1, sizeof(ProcessParamsTable) );
 
   /* clear the waveform field */
@@ -604,7 +602,7 @@ int main( int argc, char *argv[] )
         /* print version information and exit */
         fprintf( stdout, "blind hardware injection generation routine\n" 
             "Stephen Fairhurst\n");
-        XLALOutputVersionString(stderr, 0);
+        XLALOutputVCSInfo(stderr, lalAppsVCSInfoList, 0, "%% ");
         exit( 0 );
         break;
 
@@ -654,10 +652,6 @@ int main( int argc, char *argv[] )
   /* initialize the random number generator */
   randParams = XLALCreateRandomParams( randSeed );
 
-  /* null out the head of the linked list */
-  memset( &inspInjections, 0, sizeof(MetadataTable) );
-  memset( &ringInjections, 0, sizeof(MetadataTable) );
-  
 
   /*
    *
@@ -666,10 +660,10 @@ int main( int argc, char *argv[] )
    */
 
   /* create the sim_inspiral table */
-  inspInjections.simInspiralTable = inj = (SimInspiralTable *)
+  inspInjections = inj = (SimInspiralTable *)
     LALCalloc( 1, sizeof(SimInspiralTable) );
   
-  ringInjections.simRingdownTable = ringList = (SimRingdownTable *) 
+  ringInjections = ringList = (SimRingdownTable *)
     LALCalloc( 1, sizeof(SimRingdownTable) );
   
 
@@ -919,77 +913,46 @@ int main( int argc, char *argv[] )
       fname);
 
   /* open the xml file */
-  memset( &xmlfp, 0, sizeof(LIGOLwXMLStream) );
-  LAL_CALL( LALOpenLIGOLwXMLFile( &status, &xmlfp, fname), &status );
+  xmlfp = XLALOpenLIGOLwXMLFile( fname );
 
   /* write the process table */
-  snprintf( proctable.processTable->ifos, LIGOMETA_IFOS_MAX, "H1H2L1" );
-  XLALGPSTimeNow(&(proctable.processTable->end_time));
-  LAL_CALL( LALBeginLIGOLwXMLTable( &status, &xmlfp, process_table ), 
-      &status );
-  LAL_CALL( LALWriteLIGOLwXMLTable( &status, &xmlfp, proctable, 
-        process_table ), &status );
-  LAL_CALL( LALEndLIGOLwXMLTable ( &status, &xmlfp ), &status );
-  free( proctable.processTable );
+  snprintf( proctable->ifos, LIGOMETA_IFOS_MAX, "H1H2L1" );
+  XLALGPSTimeNow(&(proctable->end_time));
+  XLALWriteLIGOLwXMLProcessTable( xmlfp, proctable );
+  free( proctable );
 
   /* free the unused process param entry */
-  this_proc_param = procparams.processParamsTable;
-  procparams.processParamsTable = procparams.processParamsTable->next;
+  this_proc_param = procparams;
+  procparams = procparams->next;
   free( this_proc_param );
 
   /* write the process params table */
-  if ( procparams.processParamsTable )
+  if ( procparams )
   {
-    LAL_CALL( LALBeginLIGOLwXMLTable( &status, &xmlfp, process_params_table ), 
-        &status );
-    LAL_CALL( LALWriteLIGOLwXMLTable( &status, &xmlfp, procparams, 
-          process_params_table ), &status );
-    LAL_CALL( LALEndLIGOLwXMLTable ( &status, &xmlfp ), &status );
-    while( procparams.processParamsTable )
+    XLALWriteLIGOLwXMLProcessParamsTable( xmlfp, procparams );
+    while( procparams )
     {
-      this_proc_param = procparams.processParamsTable;
-      procparams.processParamsTable = this_proc_param->next;
+      this_proc_param = procparams;
+      procparams = this_proc_param->next;
       free( this_proc_param );
     }
   }
 
   /* write the sim_inspiral table */
-  XLALSimInspiralAssignIDs ( inspInjections.simInspiralTable, 0, 0 );
-  if ( inspInjections.simInspiralTable )
-  {
-    LAL_CALL( LALBeginLIGOLwXMLTable( &status, &xmlfp, sim_inspiral_table ), 
-        &status );
-    LAL_CALL( LALWriteLIGOLwXMLTable( &status, &xmlfp, inspInjections, 
-          sim_inspiral_table ), &status );
-    LAL_CALL( LALEndLIGOLwXMLTable ( &status, &xmlfp ), &status );
-  }
-  while ( inspInjections.simInspiralTable )
-  {
-    inj = inspInjections.simInspiralTable;
-    inspInjections.simInspiralTable = inspInjections.simInspiralTable->next;
-    XLALFreeSimInspiral( &inj );
-  }
+  XLALSimInspiralAssignIDs ( inspInjections, 0, 0 );
+  if ( inspInjections )
+    XLALWriteLIGOLwXMLSimInspiralTable( xmlfp, inspInjections );
+  XLALDestroySimInspiralTable( inspInjections );
 
    
   /* write the sim_ringdown table */
-  if ( ringInjections.simRingdownTable )
-  {
-    LALBeginLIGOLwXMLTable( &status, &xmlfp, sim_ringdown_table );
-    LALWriteLIGOLwXMLTable( &status, &xmlfp, ringInjections,
-        sim_ringdown_table );
-    LALEndLIGOLwXMLTable ( &status, &xmlfp );
-  }
-  
-  while ( ringInjections.simRingdownTable )
-  {
-    ringList=ringInjections.simRingdownTable;
-    ringInjections.simRingdownTable = ringInjections.simRingdownTable->next;
-    LALFree( ringList );
-  }
+  if ( ringInjections )
+    XLALWriteLIGOLwXMLSimRingdownTable( xmlfp, ringInjections );
+  XLALDestroySimRingdownTable( ringInjections );
 
 
   /* close the injection file */
-  LAL_CALL( LALCloseLIGOLwXMLFile ( &status, &xmlfp ), &status );
+  XLALCloseLIGOLwXMLFile( xmlfp );
 
   /* destroy random parameters */
   XLALDestroyRandomParams( randParams );
