@@ -13,8 +13,8 @@
 *
 *  You should have received a copy of the GNU General Public License
 *  along with with program; see the file COPYING. If not, write to the
-*  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-*  MA  02111-1307  USA
+*  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+*  MA  02110-1301  USA
 **********************************************************************/
 
 #include <stdio.h>
@@ -23,12 +23,13 @@
 #include <math.h>
 #include <string.h>
 
-#include <lalapps.h>
+#include <LALAppsVCSInfo.h>
+#include <lal/LALNoiseModels.h>
 #include <lal/LALStdio.h>
 #include <lal/LALgetopt.h>
 #include <lal/LALStdlib.h>
-#include <lal/LIGOLwXMLlegacy.h>
-#include <lal/LIGOLwXMLInspiralRead.h>
+#include <lal/LIGOLwXML.h>
+#include <lal/LIGOLwXMLRead.h>
 #include <lal/Date.h>
 #include <lal/FindChirp.h>
 #include <lal/Units.h>
@@ -106,7 +107,7 @@ double chirpDist(SimInspiralTable *inj, char ifo){
 
 int main(int argc, char *argv[])
 {
-  LALStatus        status=blank_status;
+  LALStatus        XLAL_INIT_DECL(status);
   CHAR                inputfile[FILENAME_MAX];
   CHAR                outputpath[1000];
   CHAR                injtype[30];
@@ -138,7 +139,6 @@ int main(int argc, char *argv[])
   SimInspiralTable *injTable=NULL;
   SimInspiralTable this_injection;
   SimInspiralTable *headTable=NULL;
-  MetadataTable MDT;
   REAL4TimeSeries *TimeSeries;
   double max_chirp_dist=0.0;
 
@@ -279,7 +279,7 @@ int main(int argc, char *argv[])
   memset(&status,0,sizeof(status));
 
   /* Read in the input XML */
-  SimInspiralTableFromLIGOLw(&injTable,inputfile,0,0);
+  injTable = XLALSimInspiralTableFromLIGOLw(inputfile);
   headTable=injTable;
   Nsamples = (UINT4)injLength/deltaT;
 
@@ -531,18 +531,13 @@ int main(int argc, char *argv[])
 
   /* If the distances were adjusted, re-write the SimInspiral table */
   if(rewriteXML){
-    memset(&MDT,0,sizeof(MDT));
-    MDT.simInspiralTable = headTable;
-        
     fprintf(stderr,"Overwriting %s with adjusted distances\n",inputfile);
     inputfile[strlen(inputfile)-4] = 0; /* Cut off the .xml */
     strncat(inputfile,"_adj.xml",FILENAME_MAX-1);
-    xmlfp=XLALOpenLIGOLwXMLFile((const char *)inputfile);
+    xmlfp=XLALOpenLIGOLwXMLFile(inputfile);
     if(xmlfp==NULL) fprintf(stderr,"Error! Cannot open %s for writing\n",inputfile);
-    LAL_CALL( LALBeginLIGOLwXMLTable( &status, xmlfp, sim_inspiral_table ), &status );
-    LAL_CALL( LALWriteLIGOLwXMLTable( &status, xmlfp, MDT,sim_inspiral_table ), &status );
-    LAL_CALL( LALEndLIGOLwXMLTable ( &status, xmlfp ), &status );
-    LAL_CALL( LALCloseLIGOLwXMLFile ( &status, xmlfp ), &status );
+    XLALWriteLIGOLwXMLSimInspiralTable( xmlfp, headTable );
+    XLALCloseLIGOLwXMLFile( xmlfp );
   }
 
   return(0);
