@@ -15,10 +15,12 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with with program; see the file COPYING. If not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- * MA  02111-1307  USA
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA  02110-1301  USA
  */
 
+#include "config.h"
+
 #include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -34,9 +36,7 @@
 #include <lal/NRWaveInject.h>
 #include <lal/TimeSeries.h>
 #include <lal/Units.h>
-#include <lal/LALFrameL.h>
 
-#include <lalapps.h>
 #include <LALAppsVCSInfo.h>
 
 /* program info */
@@ -62,7 +62,7 @@ extern int vrbflg;
 INT4 main(INT4 argc, CHAR **argv)
 {
   /* status */
-  LALStatus status = blank_status;
+  LALStatus XLAL_INIT_DECL(status);
 
   /* counters */
   int c;
@@ -211,7 +211,7 @@ INT4 main(INT4 argc, CHAR **argv)
       case 'V':
         /* print version information and exit */
         fprintf(stdout, "Numerical Relativity Frame Generation\n");
-        XLALOutputVersionString(stderr, 0);
+        XLALOutputVCSInfo(stderr, lalAppsVCSInfoList, 0, "%% ");
         exit(0);
         break;
 
