@@ -13,8 +13,8 @@
 *
 *  You should have received a copy of the GNU General Public License
 *  along with with program; see the file COPYING. If not, write to the
-*  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-*  MA  02111-1307  USA
+*  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+*  MA  02110-1301  USA
 */
 
 /*----------------------------------------------------------------------- 
@@ -266,7 +266,6 @@
 #include <time.h>
 #include <math.h>
 
-#include <lalapps.h>
 #include <series.h>
 #include <lalappsfrutils.h>
 
@@ -282,15 +281,13 @@
 #include <lal/Calibration.h>
 #include <lal/LALFrameIO.h>
 #include <lal/FindChirp.h>
-#include <lal/FrameCalibration.h>
+#include <lal/LIGOLwXML.h>
+#include <lal/LIGOLwXMLRead.h>
 #include <lal/LIGOMetadataTables.h>
 #include <lal/LIGOMetadataUtils.h>
 #include <lal/LIGOMetadataInspiralUtils.h>
-#include <lal/LIGOLwXMLlegacy.h>
-#include <lal/LIGOLwXMLInspiralRead.h>
 #include <lal/Date.h>
 #include <lal/Units.h>
-#include <lal/LALFrameL.h>
 #include <lal/TimeSeries.h>
 
 #include <LALAppsVCSInfo.h>
@@ -302,29 +299,7 @@
 #define CVS_DATE "$Date$"
 #define PROGRAM_NAME "inspiral"
 
-
-#define ADD_SUMM_VALUE( sv_name, sv_comment, val, intval ) \
-  if ( this_summ_value ) \
-{ \
-  this_summ_value = this_summ_value->next = (SummValueTable *) \
-  LALCalloc( 1, sizeof(SummValueTable) ); \
-} \
-else \
-{ \
-  summvalue.summValueTable = this_summ_value = (SummValueTable *) \
-  LALCalloc( 1, sizeof(SummValueTable) ); \
-} \
-this_summ_value->version = 0; \
-this_summ_value->start_time = searchsumm.searchSummaryTable->in_start_time; \
-this_summ_value->end_time = searchsumm.searchSummaryTable->in_end_time; \
-this_summ_value->value = (REAL4) val; \
-this_summ_value->intvalue = (INT4) intval; \
-snprintf( this_summ_value->name, LIGOMETA_SUMMVALUE_NAME_MAX, "%s", \
-    sv_name ); \
-snprintf( this_summ_value->comment, LIGOMETA_SUMMVALUE_COMM_MAX, \
-    "%s", sv_comment ); \
-
-int arg_parse_check( int argc, char *argv[], MetadataTable procparams );
+int arg_parse_check( int argc, char *argv[], ProcessParamsTable *procparams );
 
 /*
  *
@@ -361,7 +336,6 @@ CHAR  *injChanName      = NULL;         /* the injection channel name   */
 
 REAL4 injFlow           = 0;            /* injection start frequency    */
 int   injectOverhead    = 0;            /* inject h+ into detector      */
-int   numInjections     = 0;
 SimInspiralTable *injections = NULL;
 SimInspiralTable    *thisInj = NULL;
 
@@ -378,11 +352,10 @@ CHAR comment[LIGOMETA_COMMENT_MAX];     /* process param comment        */
 int main( int argc, char *argv[] )
 {
   /* lal function variables */
-  LALStatus             status = blank_status;
+  LALStatus             XLAL_INIT_DECL(status);
 
   /* frame input data */
   LALCache     *frInCache = NULL;
-  LALCache     *calCache = NULL;
   LALFrStream     *frStream = NULL;
   FrChanIn      frChan;
   FrChanIn      injChan;
@@ -395,16 +368,11 @@ int main( int argc, char *argv[] )
   COMPLEX8FrequencySeries       injResp;
 
   /* output data */
-  MetadataTable         proctable;
-  MetadataTable         procparams;
-  MetadataTable         searchsumm;
-  MetadataTable         searchsummvars;
-  MetadataTable         siminspiral;
-  SearchSummvarsTable  *this_search_summvar;
-  MetadataTable         summvalue;
-  SummValueTable       *this_summ_value = NULL;
+  ProcessTable         *proctable;
+  ProcessParamsTable   *procparams;
+  SearchSummaryTable   *searchsumm;
   ProcessParamsTable   *this_proc_param;
-  LIGOLwXMLStream       results;
+  LIGOLwXMLStream      *results;
 
   /* counters and other variables */
   const LALUnit strainPerCount = {0,{0,0,0,0,0,1,-1},{0,0,0,0,0,0,0}};
@@ -412,12 +380,7 @@ int main( int argc, char *argv[] )
   CHAR  fname[FILENAME_MAX];
   UINT4 numPoints = 0;
   REAL8 tsLength;
-  INT8  durationNS      = 0;
-  CalibrationUpdateParams inj_calfacts;
-  REAL4 inj_alpha = 0;
-  REAL4 inj_alphabeta = 0;
   CHAR tmpChName[LALNameLength];
-  REAL8 inputDeltaT;
 
   /*
    *
@@ -432,18 +395,17 @@ int main( int argc, char *argv[] )
 
 
   /* create the process and process params tables */
-  proctable.processTable = (ProcessTable *) calloc( 1, sizeof(ProcessTable) );
-  XLALGPSTimeNow(&(proctable.processTable->start_time));
-  XLALPopulateProcessTable(proctable.processTable, PROGRAM_NAME, lalAppsVCSIdentInfo.vcsId,
+  proctable = (ProcessTable *) calloc( 1, sizeof(ProcessTable) );
+  XLALGPSTimeNow(&(proctable->start_time));
+  XLALPopulateProcessTable(proctable, PROGRAM_NAME, lalAppsVCSIdentInfo.vcsId,
       lalAppsVCSIdentInfo.vcsStatus, lalAppsVCSIdentInfo.vcsDate, 0);
-  this_proc_param = procparams.processParamsTable = (ProcessParamsTable *) 
+  this_proc_param = procparams = (ProcessParamsTable *)
     calloc( 1, sizeof(ProcessParamsTable) );
   memset( comment, 0, LIGOMETA_COMMENT_MAX * sizeof(CHAR) );
 
-  /* create the search summary and zero out the summvars table */
-  searchsumm.searchSummaryTable = (SearchSummaryTable *)
+  /* create the search summary table */
+  searchsumm = (SearchSummaryTable *)
     calloc( 1, sizeof(SearchSummaryTable) );
-  searchsummvars.searchSummvarsTable = NULL;
 
   /* zero out the outfileName */
   memset( outfileName, 0, FILENAME_MAX * sizeof(CHAR) );
@@ -452,7 +414,7 @@ int main( int argc, char *argv[] )
   arg_parse_check( argc, argv, procparams );
 
   /* wind to the end of the process params table */
-  for ( this_proc_param = procparams.processParamsTable; this_proc_param->next;
+  for ( this_proc_param = procparams; this_proc_param->next;
       this_proc_param = this_proc_param->next );
 
   /* can use LALMalloc() and LALCalloc() from here onwards */
@@ -460,21 +422,18 @@ int main( int argc, char *argv[] )
   /* fill the comment, if a user has specified on, or leave it blank */
   if ( ! *comment )
   {
-    snprintf( proctable.processTable->comment, LIGOMETA_COMMENT_MAX, " " );
-    snprintf( searchsumm.searchSummaryTable->comment, LIGOMETA_COMMENT_MAX, 
-        " " );
+    snprintf( proctable->comment, LIGOMETA_COMMENT_MAX, " " );
+    snprintf( searchsumm->comment, LIGOMETA_COMMENT_MAX, " " );
   } 
   else 
   {
-    snprintf( proctable.processTable->comment, LIGOMETA_COMMENT_MAX,
-        "%s", comment );
-    snprintf( searchsumm.searchSummaryTable->comment, LIGOMETA_COMMENT_MAX,
-        "%s", comment );
+    snprintf( proctable->comment, LIGOMETA_COMMENT_MAX, "%s", comment );
+    snprintf( searchsumm->comment, LIGOMETA_COMMENT_MAX, "%s", comment );
   }
 
 
   /* the number of nodes for a standalone job is always 1 */
-  searchsumm.searchSummaryTable->nnodes = 1;
+  searchsumm->nnodes = 1;
 
   /* initialize the raw and injection data */
   memset( &chan, 0, sizeof(REAL4TimeSeries) );
@@ -515,13 +474,6 @@ int main( int argc, char *argv[] )
     LAL_CALL( LALFrGetREAL4TimeSeries( &status, &chan, &frChan, frStream ),
         &status );
 
-    /* store the input sample rate */
-    this_search_summvar = searchsummvars.searchSummvarsTable = 
-      (SearchSummvarsTable *) LALCalloc( 1, sizeof(SearchSummvarsTable) );
-    snprintf( this_search_summvar->name, LIGOMETA_NAME_MAX,
-        "raw data sample rate" );
-    this_search_summvar->value = inputDeltaT = chan.deltaT;
-
     /* determine the number of points to get and create storage for the data */
     numPoints = (UINT4) floor( ((REAL8) inputLengthNS) / (chan.deltaT * 1.0e9) 
         + 0.5 );
@@ -539,13 +491,13 @@ int main( int argc, char *argv[] )
 
     /* store the start and end time of the raw channel in the search summary */
     /* FIXME:  loss of precision;  consider
-    searchsumm.searchSummaryTable->in_start_time = searchsumm.searchSummaryTable->in_end_time = chan.epoch;
-    XLALGPSAdd(&searchsumm.searchSummaryTable->in_end_time, chan.deltaT * (REAL8) chan.data->length);
+    searchsumm->in_start_time = searchsumm->in_end_time = chan.epoch;
+    XLALGPSAdd(&searchsumm->in_end_time, chan.deltaT * (REAL8) chan.data->length);
     */
-    searchsumm.searchSummaryTable->in_start_time = chan.epoch;
+    searchsumm->in_start_time = chan.epoch;
     tsLength = XLALGPSGetREAL8( &(chan.epoch) );
     tsLength += chan.deltaT * (REAL8) chan.data->length;
-    XLALGPSSetREAL8( &(searchsumm.searchSummaryTable->in_end_time), tsLength );
+    XLALGPSSetREAL8( &(searchsumm->in_end_time), tsLength );
 
     if ( vrbflg ) fprintf( stdout, "read channel %s from frame stream\n"
         "got %d points with deltaT %e\nstarting at GPS time %d sec %d ns\n", 
@@ -633,8 +585,8 @@ int main( int argc, char *argv[] )
       inj.epoch = gpsStartTime;
       inj.sampleUnits = lalADCCountUnit;
       snprintf( inj.name, LALNameLength, "%s:STRAIN", ifo );
-      searchsumm.searchSummaryTable->in_start_time = gpsStartTime;
-      searchsumm.searchSummaryTable->in_end_time = gpsEndTime;
+      searchsumm->in_start_time = gpsStartTime;
+      searchsumm->in_end_time = gpsEndTime;
       numPoints = (UINT4) floor( ((REAL8) inputLengthNS) / (inj.deltaT * 1.0e9) 
           + 0.5 );
     }
@@ -650,19 +602,15 @@ int main( int argc, char *argv[] )
      */
 
     /* read in the injection data from XML */
-    numInjections = SimInspiralTableFromLIGOLw( &injections, injectionFile,
-        gpsStartTime.gpsSeconds, gpsEndTime.gpsSeconds + injectSafety );
+    injections = XLALSimInspiralTableFromLIGOLw( injectionFile );
 
-    if ( numInjections < 0 )
+    if ( !injections )
     {
       fprintf( stderr, "error: cannot read injection file" );
       exit( 1 );
     }
-    else if ( numInjections )
+    else
     {
-      /* store number of injections in search summary */
-      searchsumm.searchSummaryTable->nevents = numInjections;
-
       /* set the injection start frequency */
       if ( injFlow )
       {
@@ -686,29 +634,7 @@ int main( int argc, char *argv[] )
       }
       else if ( calCacheName )
       {
-        /* generate the response function for the current time */
-        if ( vrbflg ) fprintf( stdout, 
-            "generating response function at time %d sec %d ns\n"
-            "length = %d points, deltaF = %e Hz\n",
-            injResp.epoch.gpsSeconds, injResp.epoch.gpsNanoSeconds,
-            injResp.data->length, injResp.deltaF );
-        injResp.sampleUnits = strainPerCount;
-
-        /* initialize the inj_calfacts */
-        memset( &inj_calfacts, 0, sizeof(CalibrationUpdateParams) );
-        inj_calfacts.ifo = ifo;
-        durationNS = gpsEndTimeNS - gpsStartTimeNS;
-        XLALINT8NSToGPS( &(inj_calfacts.duration), durationNS );
-
-        calCache = XLALCacheImport( calCacheName );
-        LAL_CALL( LALExtractFrameResponse( &status, &injResp, calCache, 
-              &inj_calfacts ), &status );
-        XLALDestroyCache( calCache );
-        inj_alpha = (REAL4) crealf(inj_calfacts.alpha);
-        inj_alphabeta = (REAL4) crealf(inj_calfacts.alphabeta);
-        if ( vrbflg ) fprintf( stdout, 
-            "for injections, alpha = %f and alphabeta = %f\n",
-            inj_alpha, inj_alphabeta);
+        XLAL_ERROR(XLAL_EERR, "Calibration cache no longer supported");
       }
       else 
       {
@@ -740,15 +666,11 @@ int main( int argc, char *argv[] )
             &injResp ), &status );
       snprintf( inj.name,  LALNameLength, "%s", tmpChName );
 
-      if ( vrbflg ) fprintf( stdout, "injected %d signals from %s into %s\n", 
-          numInjections, injectionFile, inj.name );
+      if ( vrbflg ) fprintf( stdout, "injected signals from %s into %s\n",
+          injectionFile, inj.name );
 
       LAL_CALL( LALCDestroyVector( &status, &(injResp.data) ), &status );
     }
-    else
-    {
-      if ( vrbflg ) fprintf( stdout, "no injections in this data\n" );
-    }
   }
 
   /* 
@@ -911,7 +833,6 @@ int main( int argc, char *argv[] )
 
 
   /* open the output xml file */
-  memset( &results, 0, sizeof(LIGOLwXMLStream) );
   if( userTag && outCompress )
   {
     if(snprintf( fname, FILENAME_MAX, "%s_%s-%d-%d.xml.gz", outfileName,
@@ -942,103 +863,38 @@ int main( int argc, char *argv[] )
   }
 
   if ( vrbflg ) fprintf( stdout, "writing XML data to %s...\n", fname );
-  LAL_CALL( LALOpenLIGOLwXMLFile( &status, &results, fname ), &status );
+  results = XLALOpenLIGOLwXMLFile( fname );
 
   /* write the process table */
   if ( vrbflg ) fprintf( stdout, "  process table...\n" );
-  snprintf( proctable.processTable->ifos, LIGOMETA_IFOS_MAX, "%s", ifo );
-  XLALGPSTimeNow(&(proctable.processTable->end_time));
-  LAL_CALL( LALBeginLIGOLwXMLTable( &status, &results, process_table ), 
-      &status );
-  LAL_CALL( LALWriteLIGOLwXMLTable( &status, &results, proctable, 
-        process_table ), &status );
-  LAL_CALL( LALEndLIGOLwXMLTable ( &status, &results ), &status );
-  free( proctable.processTable );
+  snprintf( proctable->ifos, LIGOMETA_IFOS_MAX, "%s", ifo );
+  XLALGPSTimeNow(&(proctable->end_time));
+  XLALWriteLIGOLwXMLProcessTable( results, proctable );
+  free( proctable );
 
   /* write the process params table */
   if ( vrbflg ) fprintf( stdout, "  process_params table...\n" );
-  LAL_CALL( LALBeginLIGOLwXMLTable( &status, &results, process_params_table ), 
-      &status );
-  LAL_CALL( LALWriteLIGOLwXMLTable( &status, &results, procparams, 
-        process_params_table ), &status );
-  LAL_CALL( LALEndLIGOLwXMLTable ( &status, &results ), &status );
-  while( procparams.processParamsTable )
-  {
-    this_proc_param = procparams.processParamsTable;
-    procparams.processParamsTable = this_proc_param->next;
-    free( this_proc_param );
-  }
+  XLALWriteLIGOLwXMLProcessParamsTable( results, procparams );
+  XLALDestroyProcessParamsTable( procparams );
 
   /* write the search summary table */
   if ( vrbflg ) fprintf( stdout, "  search_summary table...\n" );
-  LAL_CALL( LALBeginLIGOLwXMLTable( &status, &results, 
-        search_summary_table ), &status );
-  LAL_CALL( LALWriteLIGOLwXMLTable( &status, &results, searchsumm, 
-        search_summary_table ), &status );
-  LAL_CALL( LALEndLIGOLwXMLTable ( &status, &results ), &status );
-
-  /* write the search summvars table */
-  if ( searchsummvars.searchSummvarsTable )
-  {
-    if ( vrbflg ) fprintf( stdout, "  search_summvars table...\n" );
-    LAL_CALL( LALBeginLIGOLwXMLTable( &status, &results, 
-          search_summvars_table ), &status );
-    LAL_CALL( LALWriteLIGOLwXMLTable( &status, &results, searchsummvars, 
-          search_summvars_table ), &status );
-    LAL_CALL( LALEndLIGOLwXMLTable ( &status, &results ), &status );
-    while( searchsummvars.searchSummvarsTable )
-    {
-      this_search_summvar = searchsummvars.searchSummvarsTable;
-      searchsummvars.searchSummvarsTable = this_search_summvar->next;
-      LALFree( this_search_summvar );
-    }
-  }
-  /* write the summ_value table with the calibration data used for injections */
-  if ( frInCacheName && injectionFile)
-  {
-    ADD_SUMM_VALUE( "calibration alpha", "injection", inj_alpha, 0 );
-    ADD_SUMM_VALUE( "calibration alphabeta", "injection", inj_alphabeta, 0 );
-
-    LAL_CALL( LALBeginLIGOLwXMLTable( &status, &results, summ_value_table ), 
-        &status );
-    LAL_CALL( LALWriteLIGOLwXMLTable( &status, &results, summvalue, 
-          summ_value_table ), &status );
-    LAL_CALL( LALEndLIGOLwXMLTable ( &status, &results ), &status );
-
-
-    while ( summvalue.summValueTable )
-    {
-      this_summ_value = summvalue.summValueTable;
-      summvalue.summValueTable = summvalue.summValueTable->next;
-      LALFree( this_summ_value );
-    }
-  }
+  XLALWriteLIGOLwXMLSearchSummaryTable( results, searchsumm );
 
   /* free the search summary table */
-  free( searchsumm.searchSummaryTable );
+  free( searchsumm );
 
   /* write the sim_inspiral table */
   if ( injections )
   {
     if ( vrbflg ) fprintf( stdout, "sim_inspiral... " );
-    siminspiral.simInspiralTable = injections;
-    LAL_CALL( LALBeginLIGOLwXMLTable( &status, &results, 
-          sim_inspiral_table ), &status );
-    LAL_CALL( LALWriteLIGOLwXMLTable( &status, &results, siminspiral, 
-          sim_inspiral_table ), &status );
-    LAL_CALL( LALEndLIGOLwXMLTable( &status, &results ), &status );
-
+    XLALWriteLIGOLwXMLSimInspiralTable( results, injections );
     /* free the temporary memory containing the events */
-    while ( injections )
-    {
-      thisInj = injections;
-      injections = injections->next;
-      XLALFreeSimInspiral( &thisInj );
-    }
+    XLALDestroySimInspiralTable( injections );
   }
 
   /* close the output xml file */
-  LAL_CALL( LALCloseLIGOLwXMLFile ( &status, &results ), &status );
+  XLALCloseLIGOLwXMLFile( results );
   if ( vrbflg ) fprintf( stdout, "done. XML file closed\n" );
 
   /* free the rest of the memory, check for memory leaks and exit */
@@ -1117,7 +973,7 @@ static void print_usage(char *program)
       "\n", program );
 }
 
-int arg_parse_check( int argc, char *argv[], MetadataTable procparams )
+int arg_parse_check( int argc, char *argv[], ProcessParamsTable *procparams )
 {
   /* LALgetopt arguments */
   struct LALoption long_options[] =
@@ -1159,7 +1015,7 @@ int arg_parse_check( int argc, char *argv[], MetadataTable procparams )
     {0, 0, 0, 0}
   };
   int c;
-  ProcessParamsTable *this_proc_param = procparams.processParamsTable;
+  ProcessParamsTable *this_proc_param = procparams;
 
 
   /*
@@ -1520,7 +1376,7 @@ int arg_parse_check( int argc, char *argv[], MetadataTable procparams )
         /* print version information and exit */
         fprintf( stdout, "LIGO/LSC Inspiral Injection Program\n" 
             "Steve Fairhurst <sfairhur@gravity.phys.uwm.edu>\n");
-        XLALOutputVersionString(stderr, 0);
+        XLALOutputVCSInfo(stderr, lalAppsVCSInfoList, 0, "%% ");
         exit( 0 );
         break;
 
