@@ -32,7 +32,7 @@ class InspiralAnalysisJob(pipeline.AnalysisJob, pipeline.CondorDAGJob):
   are set, the stdout and stderr from the job are directed to the logs
   directory. The path to the executable is determined from the ini file.
   """
-  def __init__(self,cp,sections,exec_name,extension='xml',dax=False):
+  def __init__(self,cp,sections,exec_name,extension='xml'):
     """
     cp = ConfigParser object from which options are read.
     sections = sections of the ConfigParser that get added to the opts
@@ -43,20 +43,13 @@ class InspiralAnalysisJob(pipeline.AnalysisJob, pipeline.CondorDAGJob):
     universe = cp.get('condor','universe')
     executable = cp.get('condor',exec_name)
     pipeline.CondorDAGJob.__init__(self,universe,executable)
-    pipeline.AnalysisJob.__init__(self,cp,dax)
+    pipeline.AnalysisJob.__init__(self,cp)
     self.add_condor_cmd('copy_to_spool','False')
-    self.set_grid_site('local')
     self.__use_gpus = cp.has_option('condor', 'use-gpus')
 
     mycp = copy.deepcopy(cp)
     for sec in sections:
       if mycp.has_section(sec):
-        # check to see if the job should run on a remote site
-        if mycp.has_option(sec,'remote-sites'):
-          remotesites = mycp.get(sec,'remote-sites')
-          mycp.remove_option(sec,'remote-sites')
-          self.set_grid_site(remotesites)
-
         # add all the other options as arguments to the code
         self.add_ini_opts(mycp, sec)
 
@@ -107,13 +100,13 @@ class InspiralPlottingJob(InspiralAnalysisJob):
   The InspiralPlottingJob class will assign options common to all plotting
   jobs. Currently this is only MPLCONFIGDIR.
   """
-  def __init__(self,cp,sections,exec_name,extension='xml',dax=False):
+  def __init__(self,cp,sections,exec_name,extension='xml'):
     """
     cp = ConfigParser object from which options are read.
     sections = sections of the ConfigParser that get added to the opts
     exec_name = exec_name name in ConfigParser
     """
-    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension)
     self.add_condor_cmd('getenv','True')
     if cp.has_option('pipeline','matplotlibdir'):
       MPLConfigPath = cp.get('pipeline','matplotlibdir')
@@ -129,7 +122,7 @@ class TmpltBankJob(InspiralAnalysisJob):
   runs in the universe specfied in the ini file. The path to the executable
   is determined from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     cp = ConfigParser object from which options are read.
     """
@@ -142,7 +135,7 @@ class TmpltBankJob(InspiralAnalysisJob):
          have_pycbc=True
          cp.set('condor', 'universe', 'vanilla')
 
-    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension)
 
     if have_pycbc:
         self.add_condor_cmd('getenv', 'True')
@@ -157,14 +150,14 @@ class InspInjJob(InspiralAnalysisJob):
   job runs in the universe specified in the ini file. The path to the
   executable is determined from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     cp = ConfigParser object from which options are read.
     """
     exec_name = 'inspinj'
     sections = ['inspinj']
     extension = 'xml'
-    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension)
     self.set_universe('vanilla')
 
     self.__listDone=[]
@@ -189,14 +182,14 @@ class BbhInjJob(InspiralAnalysisJob):
   job runs in the universe specified in the ini file. The path to the
   executable is determined from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     cp = ConfigParser object from which options are read.
     """
     exec_name = 'bbhinj'
     sections = ['bbhinj']
     extension = 'xml'
-    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension)
 
 
 class RandomBankJob(InspiralAnalysisJob):
@@ -207,14 +200,14 @@ class RandomBankJob(InspiralAnalysisJob):
   universe specfied in the ini file. The path to the executable is determined
   from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     cp = ConfigParser object from which options are read.
     """
     exec_name = 'randombank'
     sections = ['randombank']
     extension = 'xml'
-    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension)
 
 
 class SplitBankJob(InspiralAnalysisJob):
@@ -225,14 +218,14 @@ class SplitBankJob(InspiralAnalysisJob):
   universe specfied in the ini file. The path to the executable is determined
   from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     cp = ConfigParser object from which options are read.
     """
     exec_name = 'splitbank'
     sections = ['splitbank']
     extension = 'xml'
-    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension)
 
 
 class InspiralJob(InspiralAnalysisJob):
@@ -245,7 +238,7 @@ class InspiralJob(InspiralAnalysisJob):
   checks are done to ensure a successful run and the necessary Condor
   commands are added.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     cp = ConfigParser object from which options are read.
     """
@@ -259,7 +252,7 @@ class InspiralJob(InspiralAnalysisJob):
          cp.set('condor', 'universe', 'vanilla')
          cp.remove_option('inspiral', 'pycbc')
 
-    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension)
     self.add_condor_cmd('environment',"KMP_LIBRARY=serial;MKL_SERIAL=yes")
     self.add_condor_cmd('request_memory', '1000')
 
@@ -301,14 +294,14 @@ class InspiralCkptJob(InspiralAnalysisJob):
   is determined from the ini file.
   This one checkpoints.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     cp = ConfigParser object from which options are read.
     """
     exec_name = 'inspiral'
     sections = []
     extension = 'xml'
-    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension)
     self.add_short_opt('_condor_relocatable', '')
 
 
@@ -320,14 +313,14 @@ class PTFInspiralJob(InspiralAnalysisJob):
   runs in the universe specfied in the ini file. The path to the executable
   is determined from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     cp = ConfigParser object from which options are read.
     """
     exec_name = 'coh_PTF_inspiral'
     sections = ['coh_PTF_inspiral']
     extension = 'xml'
-    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension)
     ramValue = 1390
     if cp.has_section('coh_PTF_inspiral-meta'):
       if cp.has_option('coh_PTF_inspiral-meta','minimum-ram'):
@@ -335,21 +328,6 @@ class PTFInspiralJob(InspiralAnalysisJob):
     self.add_condor_cmd('request_memory', '%d' %(ramValue))
 
 
-class PTFSpinCheckerJob(InspiralAnalysisJob):
-  """
-  A coh_PTF spin checker job
-  """
-  def __init__(self,cp,dax=False):
-    """
-    cp = ConfigParser object from which options are read.
-    """
-    exec_name = 'coh_PTF_spin_checker'
-    sections = ['coh_PTF_spin_checker']
-    extension = 'xml'
-    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension,dax)
-    self.add_condor_cmd('request_memory', '1400')
-
-
 class TrigbankJob(InspiralAnalysisJob):
   """
   A lalapps_trigbank job used by the inspiral pipeline. The static
@@ -358,14 +336,14 @@ class TrigbankJob(InspiralAnalysisJob):
   always runs in the scheduler universe. The path to the executable is
   determined from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     cp = ConfigParser object from which options are read.
     """
     exec_name = 'trigbank'
     sections = ['trigbank']
     extension = 'xml'
-    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension)
 
 
 class IncaJob(InspiralAnalysisJob):
@@ -375,14 +353,14 @@ class IncaJob(InspiralAnalysisJob):
   the job are directed to the logs directory.  The path to the executable is
   determined from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     cp = ConfigParser object from which options are read.
     """
     exec_name = 'inca'
     sections = ['inca']
     extension = 'xml'
-    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension)
 
 
 class ThincaJob(InspiralAnalysisJob):
@@ -392,7 +370,7 @@ class ThincaJob(InspiralAnalysisJob):
   the job are directed to the logs directory.  The path to the executable is
   determined from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     cp = ConfigParser object from which options are read.
     """
@@ -400,7 +378,7 @@ class ThincaJob(InspiralAnalysisJob):
     #sections = ['thinca']
     sections = []
     extension = 'xml'
-    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension)
     if cp.has_section('thinca'):
       self.add_ini_opts(cp,'thinca')
 
@@ -435,15 +413,14 @@ class ThincaToCoincJob(InspiralAnalysisJob):
   A ThincaToCoinc job. The static options are read from the
   section [thinca_to_coinc] in the ini file.
   """
-  def __init__(self, cp, dax = False):
+  def __init__(self, cp):
     """
     @param cp: ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'thinca_to_coinc'
     sections = ['thinca_to_coinc']
     extension = 'xml'
-    InspiralAnalysisJob.__init__(self, cp, sections, exec_name, extension, dax)
+    InspiralAnalysisJob.__init__(self, cp, sections, exec_name, extension)
     self.add_condor_cmd('getenv', 'True')
     self.__experiment_start_time = None
     self.__experiment_end_time = None
@@ -492,10 +469,9 @@ class HWinjPageJob(InspiralAnalysisJob):
   A HWinjPageJob, runs the hardware injection page script on the
   output of the pipeline
   """
-  def __init__(self, cp, dax = False):
+  def __init__(self, cp):
     """
     @param cp: ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = "hardware_inj_page"
     universe = "vanilla"
@@ -503,7 +479,7 @@ class HWinjPageJob(InspiralAnalysisJob):
     extension = 'html'
     executable = cp.get('condor',exec_name)
     pipeline.CondorDAGJob.__init__(self, universe, executable)
-    pipeline.AnalysisJob.__init__(self, cp, dax)
+    pipeline.AnalysisJob.__init__(self, cp)
     self.add_condor_cmd('getenv','True')
     self.set_stdout_file('logs/' + exec_name + '-$(cluster)-$(process).out')
     self.set_stderr_file('logs/' + exec_name + '-$(cluster)-$(process).err')
@@ -515,15 +491,14 @@ class SireJob(InspiralAnalysisJob):
   the job are directed to the logs directory. The path to the executable is
   determined from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     @param cp = ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'sire'
     sections = ['sire']
     extension = 'xml'
-    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension)
 
     # sire currently doesn't take GPS start/end times
     self.set_stdout_file('logs/sire-$(macroifo)-$(cluster)-$(process).out')
@@ -536,15 +511,14 @@ class CoireJob(InspiralAnalysisJob):
   the job are directed to the logs directory. The path to the executable is
   determined from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     @param cp = ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'coire'
     sections = ['coire']
     extension = 'xml'
-    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension)
 
     # coire currently doesn't take GPS start/end times
     self.set_stdout_file('logs/coire-$(macroifo)-$(cluster)-$(process).out')
@@ -556,15 +530,14 @@ class FrJoinJob(InspiralAnalysisJob):
   A lalapps_frjoin job used by the inspiral pipeline. The path to the
   executable is determined from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     @param cp = ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'frjoin'
     sections = []
     extension = 'gwf'
-    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension)
 
     # frjoin currently doesn't take GPS start/end times
     self.set_stdout_file('logs/frjoin-$(cluster)-$(process).out')
@@ -578,15 +551,14 @@ class CohBankJob(InspiralAnalysisJob):
   stderr from the job are directed to the logs directory.  The path to the
   executable is determined from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     @param cp = ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'cohbank'
     sections = ['cohbank']
     extension = 'xml'
-    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension)
 
 
 class InspiralCoherentJob(InspiralAnalysisJob):
@@ -597,15 +569,14 @@ class InspiralCoherentJob(InspiralAnalysisJob):
   runs in the universe specfied in the ini file. The path to the executable
   is determined from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     @param cp = ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'inspiral'
     sections = ['data']
     extension = 'xml'
-    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension)
     self.add_condor_cmd('environment',"KMP_LIBRARY=serial;MKL_SERIAL=yes")
 
 
@@ -616,15 +587,14 @@ class CohInspBankJob(InspiralAnalysisJob):
   stderr from the job are directed to the logs directory.  The path to the
   executable is determined from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     @param cp = ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'cohinspbank'
     sections = ['cohinspbank']
     extension = 'xml'
-    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension)
 
 
 class ChiaJob(InspiralAnalysisJob):
@@ -634,15 +604,14 @@ class ChiaJob(InspiralAnalysisJob):
   stderr from the job are directed to the logs directory.  The path to the
   executable is determined from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     @param cp = ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'chia'
     sections = ['chia']
     extension = 'xml'
-    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension)
 
 
 class CohireJob(InspiralAnalysisJob):
@@ -651,15 +620,14 @@ class CohireJob(InspiralAnalysisJob):
   the job are directed to the logs directory. The path to the executable is
   determined from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     @param cp = ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'cohire'
     sections = ['cohire']
     extension = 'xml'
-    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension)
 
     # cohire currently doesn't take GPS start/end times
     self.set_stdout_file('logs/cohire-$(macroifo)-$(cluster)-$(process).out')
@@ -671,15 +639,14 @@ class InjFindJob(InspiralAnalysisJob):
   An injfind job. The static options are read from the [injfind]
   section in the cp file.
   """
-  def __init__(self, cp, dax = False):
+  def __init__(self, cp):
     """
     @param cp: a ConfigParser object from which the options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'injfind'
     sections = ['injfind']
     extension = 'xml'
-    InspiralAnalysisJob.__init__(self, cp, sections, exec_name, extension, dax)
+    InspiralAnalysisJob.__init__(self, cp, sections, exec_name, extension)
     self.add_condor_cmd('getenv', 'True')
     # overwrite standard log file names
     self.set_stdout_file('logs/' + exec_name + '-$(cluster)-$(process).out')
@@ -1021,13 +988,6 @@ class InspiralNode(InspiralAnalysisNode):
     """
     InspiralAnalysisNode.__init__(self,job)
     self.__injections = None
-    self.add_pegasus_profile('condor', 'request_memory', '1000')
-
-    if job.get_use_gpus():
-      # assume all the checks have been already
-      # done by the InspiralJob instance
-      self.add_pegasus_profile('condor', '+WantGPU', 'true')
-      self.add_pegasus_profile('condor', 'Requirements', '( GPU_PRESENT =?= true)')
 
   def set_bank(self,bank):
     self.add_var_opt('bank-file', bank)
@@ -1110,7 +1070,6 @@ class PTFInspiralNode(InspiralAnalysisNode):
     InspiralAnalysisNode.__init__(self,job)
     self.__injections = None
     self.set_zip_output(True)
-    self.add_pegasus_profile('condor', 'request_memory', '1400')
 
   def set_spin_bank(self,bank):
     self.add_var_opt('spin-bank', bank)
@@ -1151,7 +1110,6 @@ class PTFSpinCheckerNode(InspiralAnalysisNode):
     """
     InspiralAnalysisNode.__init__(self,job)
     self.__injections = None
-    self.add_pegasus_profile('condor', 'request_memory', '1400')
 
   def set_bank(self,bank):
     self.add_var_opt('bank-file', bank)
@@ -2269,15 +2227,14 @@ class PlotInspiralrangeJob(InspiralPlottingJob):
   are directed to the logs directory.  The path to the executable is
   determined from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     @param cp = ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'plotinspiralrange'
     sections = ['plotinspiralrange']
     extension = 'html'
-    InspiralPlottingJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralPlottingJob.__init__(self,cp,sections,exec_name,extension)
 
 class PlotInspiralrangeNode(InspiralPlottingNode):
   """
@@ -2299,15 +2256,14 @@ class PlotInspiralJob(InspiralPlottingJob):
   are directed to the logs directory.  The path to the executable is
   determined from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     @param cp = ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'plotinspiral'
     sections = ['plotinspiral']
     extension = 'html'
-    InspiralPlottingJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralPlottingJob.__init__(self,cp,sections,exec_name,extension)
 
 class PlotInspiralNode(InspiralPlottingNode):
   """
@@ -2328,15 +2284,14 @@ class PlotThincaJob(InspiralPlottingJob):
   are directed to the logs directory.  The path to the executable is
   determined from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     @param cp = ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'plotthinca'
     sections = ['plotthinca']
     extension = 'html'
-    InspiralPlottingJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralPlottingJob.__init__(self,cp,sections,exec_name,extension)
     self.add_condor_cmd('request_memory', '2500')
 
 class PlotThincaNode(InspiralPlottingNode):
@@ -2359,15 +2314,14 @@ class PlotCohsnrJob(InspiralPlottingJob):
   are directed to the logs directory.  The path to the executable is
   determined from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     @param cp = ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'plotcohsnr'
     sections = ['plotcohsnr']
     extension = 'html'
-    InspiralPlottingJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralPlottingJob.__init__(self,cp,sections,exec_name,extension)
 
 class PlotCohsnrNode(InspiralPlottingNode):
   """
@@ -2389,15 +2343,14 @@ class PlotNumtemplatesJob(InspiralPlottingJob):
   are directed to the logs directory.  The path to the executable is
   determined from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     @param cp = ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'plotnumtemplates'
     sections = ['plotnumtemplates']
     extension = 'html'
-    InspiralPlottingJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralPlottingJob.__init__(self,cp,sections,exec_name,extension)
 
 class PlotNumtemplatesNode(InspiralPlottingNode):
   """
@@ -2418,15 +2371,14 @@ class PlotEthincaJob(InspiralPlottingJob):
   are directed to the logs directory.  The path to the executable is
   determined from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     @param cp = ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'plotethinca'
     sections = ['plotethinca']
     extension = 'html'
-    InspiralPlottingJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralPlottingJob.__init__(self,cp,sections,exec_name,extension)
     self.add_condor_cmd('request_memory', '2500')
 
 class PlotEthincaNode(InspiralPlottingNode):
@@ -2448,15 +2400,14 @@ class PlotInspmissedJob(InspiralPlottingJob):
   are directed to the logs directory.  The path to the executable is
   determined from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     @param cp = ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'plotinspmissed'
     sections = ['plotinspmissed']
     extension = 'html'
-    InspiralPlottingJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralPlottingJob.__init__(self,cp,sections,exec_name,extension)
 
 class PlotInspmissedNode(InspiralPlottingNode):
   """
@@ -2477,15 +2428,14 @@ class PlotEffdistcutJob(InspiralPlottingJob):
   are directed to the logs directory.  The path to the executable is
   determined from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     @param cp = ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'ploteffdistcut'
     sections = ['ploteffdistcut']
     extension = 'html'
-    InspiralPlottingJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralPlottingJob.__init__(self,cp,sections,exec_name,extension)
 
 class PlotEffdistcutNode(InspiralPlottingNode):
   """
@@ -2507,15 +2457,14 @@ class PlotInspinjJob(InspiralPlottingJob):
   are directed to the logs directory.  The path to the executable is
   determined from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     @param cp = ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'plotinspinj'
     sections = ['plotinspinj']
     extension = 'html'
-    InspiralPlottingJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralPlottingJob.__init__(self,cp,sections,exec_name,extension)
     self.add_condor_cmd('request_memory', '2500')
 
 class PlotInspinjNode(InspiralPlottingNode):
@@ -2537,15 +2486,14 @@ class PlotSnrchiJob(InspiralPlottingJob):
   are directed to the logs directory.  The path to the executable is
   determined from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     @param cp = ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'plotsnrchi'
     sections = ['plotsnrchi']
     extension = 'html'
-    InspiralPlottingJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralPlottingJob.__init__(self,cp,sections,exec_name,extension)
     self.add_condor_cmd('request_memory', '2500')
 
 class PlotSnrchiNode(InspiralPlottingNode):
@@ -2567,15 +2515,14 @@ class PlotGRBtimeslideStatsJob(InspiralAnalysisJob):
   are directed to the logs directory.  The path to the executable is
   determined from the ini file.
   """
-  def __init__(self,cp,dax=False):
+  def __init__(self,cp):
     """
     @param cp = ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'pylal_grbtimeslide_stats'
     sections = ['grbtimeslidestats']
     extension = 'html'
-    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension,dax)
+    InspiralAnalysisJob.__init__(self,cp,sections,exec_name,extension)
     self.add_condor_cmd('getenv', 'True')
 
 class PlotGRBtimeslideStatsNode(InspiralAnalysisNode):
@@ -2595,15 +2542,14 @@ class MiniFollowupsJob(InspiralPlottingJob):
   A minifollowups job. Static options are read from the
   [minifollowups] section in the ini file.
   """
-  def __init__(self, cp, dax = False):
+  def __init__(self, cp):
     """
     @param cp: ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'minifollowups'
     sections = ['minifollowups','omega-scans']
     extension = None
-    InspiralPlottingJob.__init__(self, cp, sections, exec_name, extension, dax)
+    InspiralPlottingJob.__init__(self, cp, sections, exec_name, extension)
     self.add_condor_cmd('request_memory', '2500')
 
   def set_time_slides(self):
@@ -2744,14 +2690,13 @@ class DBSimplifyJob(pipeline.SqliteJob):
   A DBSimplify job. The static options are read from the section
   [dbsimplify] in the ini file.
   """
-  def __init__(self, cp, dax = False):
+  def __init__(self, cp):
     """
     @param cp: ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'dbsimplify'
     sections = ['dbsimplify']
-    pipeline.SqliteJob.__init__(self, cp, sections, exec_name, dax)
+    pipeline.SqliteJob.__init__(self, cp, sections, exec_name)
 
 
 class DBSimplifyNode(pipeline.SqliteNode):
@@ -2770,14 +2715,13 @@ class ComputeDurationsJob(pipeline.SqliteJob):
   A ComputeDurations job. The static options are read from the section
   [compute_durations] in the ini file.
   """
-  def __init__(self, cp, dax = False):
+  def __init__(self, cp):
     """
     @param cp: ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'compute_durations'
     sections = ['compute_durations']
-    pipeline.SqliteJob.__init__(self, cp, sections, exec_name, dax)
+    pipeline.SqliteJob.__init__(self, cp, sections, exec_name)
 
 
 class ComputeDurationsNode(pipeline.SqliteNode):
@@ -2796,14 +2740,13 @@ class DBAddInjJob(pipeline.SqliteJob):
   A DBAddInj job. The static options are read from the section
   [dbaddinj] in the ini file.
   """
-  def __init__(self, cp, dax = False):
+  def __init__(self, cp):
     """
     @param cp: ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'dbaddinj'
     sections = ['dbaddinj']
-    pipeline.SqliteJob.__init__(self, cp, sections, exec_name, dax)
+    pipeline.SqliteJob.__init__(self, cp, sections, exec_name)
 
 
 class DBAddInjNode(pipeline.SqliteNode):
@@ -2850,14 +2793,13 @@ class RepopCoincJob(pipeline.SqliteJob):
   A repop_coinc job. The static options are read from the section
   [repop_coinc] in the ini file.
   """
-  def __init__(self, cp, dax = False):
+  def __init__(self, cp):
     """
     @param cp: ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'repop_coinc'
     sections = ['repop_coinc']
-    pipeline.SqliteJob.__init__(self, cp, sections, exec_name, dax)
+    pipeline.SqliteJob.__init__(self, cp, sections, exec_name)
 
 
 class RepopCoincNode(pipeline.SqliteNode):
@@ -2876,14 +2818,13 @@ class DBInjFindJob(pipeline.SqliteJob):
   A dbinjfind job. The static options are read from the section
   [dbinjfind] in the ini file.
   """
-  def __init__(self, cp, dax = False):
+  def __init__(self, cp):
     """
     @param cp: ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'dbinjfind'
     sections = ['dbinjfind']
-    pipeline.SqliteJob.__init__(self, cp, sections, exec_name, dax)
+    pipeline.SqliteJob.__init__(self, cp, sections, exec_name)
 
 
 class DBInjFindNode(pipeline.SqliteNode):
@@ -2902,14 +2843,13 @@ class ClusterCoincsJob(pipeline.SqliteJob):
   A cluster coincs job. The static options are read from the section
   [cluster_coincs] in the ini file.
   """
-  def __init__(self, cp, dax = False):
+  def __init__(self, cp):
     """
     @param cp: ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'cluster_coincs'
     sections = ['cluster_coincs']
-    pipeline.SqliteJob.__init__(self, cp, sections, exec_name, dax)
+    pipeline.SqliteJob.__init__(self, cp, sections, exec_name)
 
 
 class ClusterCoincsNode(pipeline.SqliteNode):
@@ -2928,14 +2868,13 @@ class CFarJob(pipeline.SqliteJob):
   A cfar job. The static options are read from the section [cfar] in
   the ini file.
   """
-  def __init__(self, cp, sections, dax = False):
+  def __init__(self, cp, sections):
     """
     @param cp: ConfigParser object from which options are read.
     @param sections: list of sections for cp to read from
-    @param dax UNDOCUMENTED
     """
     exec_name = 'cfar'
-    pipeline.SqliteJob.__init__(self, cp, sections, exec_name, dax)
+    pipeline.SqliteJob.__init__(self, cp, sections, exec_name)
 
 
 class CFarNode(pipeline.SqliteNode):
@@ -2953,14 +2892,13 @@ class LigolwCBCPrintJob(pipeline.SqliteJob):
   """
   A LigolwCBCPrintJob is a generic job class for ligolw_cbc_print* programs, e.g., ligolw_cbc_printlc.
   """
-  def __init__(self, cp, exec_name, sections, dax = False):
+  def __init__(self, cp, exec_name, sections):
     """
     @param cp: ConfigParser object from which options are read.
     @param exec_name UNDOCUMENTED
     @param sections: list of sections for cp to read from
-    @param dax UNDOCUMENTED
     """
-    pipeline.SqliteJob.__init__(self, cp, sections, exec_name, dax)
+    pipeline.SqliteJob.__init__(self, cp, sections, exec_name)
 
 
 class LigolwCBCPrintNode(pipeline.SqliteNode):
@@ -3141,14 +3079,13 @@ class PlotSlidesJob(pipeline.SqliteJob):
   A plotslides job. The static options are read from the sections [plot_input]
   and [plotslides].
   """
-  def __init__(self, cp, dax = False):
+  def __init__(self, cp):
     """
     @param cp: ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'plotslides'
     sections = ['plot_input', 'plotslides']
-    pipeline.SqliteJob.__init__(self, cp, sections, exec_name, dax)
+    pipeline.SqliteJob.__init__(self, cp, sections, exec_name)
 
   def set_plot_playground_only(self):
     """
@@ -3173,14 +3110,13 @@ class PlotCumhistJob(pipeline.SqliteJob):
   A plotcumhist job. The static options are read from the sections [plot_input] and
   [plotcumhist].
   """
-  def __init__(self, cp, dax = False):
+  def __init__(self, cp):
     """
     @param cp: ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'plotcumhist'
     sections = ['plot_input', 'plotcumhist']
-    pipeline.SqliteJob.__init__(self, cp, sections, exec_name, dax)
+    pipeline.SqliteJob.__init__(self, cp, sections, exec_name)
 
   def set_plot_playground_only(self):
     """
@@ -3204,14 +3140,13 @@ class PlotIfarJob(pipeline.SqliteJob):
   """
   A plotifar job. The static options are read from the [plotifar] section.
   """
-  def __init__(self, cp, dax = False):
+  def __init__(self, cp):
     """
     @param cp: ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'plotifar'
     sections = ['plot_input','plotifar']
-    pipeline.SqliteJob.__init__(self, cp, sections, exec_name, dax)
+    pipeline.SqliteJob.__init__(self, cp, sections, exec_name)
 
 
 class PlotIfarNode(pipeline.SqliteNode):
@@ -3242,14 +3177,13 @@ class PlotFMJob(pipeline.SqliteJob):
   """
   A plotfm job. The static options are read from the [plotfm] seciont.
   """
-  def __init__(self, cp, dax = False):
+  def __init__(self, cp):
     """
     @param cp: ConfigParser object from which objects are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'plotfm'
     sections = ['plot_input', 'plotfm']
-    pipeline.SqliteJob.__init__(self, cp, sections, exec_name, dax)
+    pipeline.SqliteJob.__init__(self, cp, sections, exec_name)
 
 class PlotFMNode(pipeline.SqliteNode):
   """
@@ -3308,13 +3242,12 @@ class SearchVolumeJob(pipeline.SqliteJob):
   volume above the loudest event (open box) or FAR=1/livetime
   (closed box).
   """
-  def __init__(self, cp, dax = False):
+  def __init__(self, cp):
     """
     @param cp: ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = 'search_volume'
-    pipeline.SqliteJob.__init__(self, cp, ['search-volume'], exec_name, dax)
+    pipeline.SqliteJob.__init__(self, cp, ['search-volume'], exec_name)
     self.add_condor_cmd('environment',"KMP_LIBRARY=serial;MKL_SERIAL=yes")
 
 class SearchVolumeNode(pipeline.SqliteNode):
@@ -3347,14 +3280,13 @@ class SearchUpperLimitJob(pipeline.SqliteJob):
   A search upper limit job. Compute the search upper limit from the search
   volume output. Generates upper limit plots.
   """
-  def __init__(self, cp, dax = False):
+  def __init__(self, cp):
     """
     @param cp: ConfigParser object from which options are read.
     sections: list of sections for cp to read from
-    @param dax UNDOCUMENTED
     """
     exec_name = 'search_upper_limit'
-    pipeline.SqliteJob.__init__(self, cp, ['upper-limit'], exec_name, dax)
+    pipeline.SqliteJob.__init__(self, cp, ['upper-limit'], exec_name)
     self.add_condor_cmd('environment',"KMP_LIBRARY=serial;MKL_SERIAL=yes")
 
 class SearchUpperLimitNode(pipeline.SqliteNode):
@@ -3386,17 +3318,16 @@ class MVSCDagGenerationJob(InspiralAnalysisJob):
   """
   a job that generates the mvsc_dag, which will be run as an external subdag
   """
-  def __init__(self, cp, dax = False):
+  def __init__(self, cp):
     """
     @param cp: ConfigParser object from which options are read.
-    @param dax UNDOCUMENTED
     """
     exec_name = "mvsc_dag"
     universe = "vanilla"
     sections = "[mvsc_dag]"
     executable = cp.get('condor',exec_name)
     pipeline.CondorDAGJob.__init__(self, universe, executable)
-    pipeline.AnalysisJob.__init__(self, cp, dax)
+    pipeline.AnalysisJob.__init__(self, cp)
     self.add_condor_cmd('getenv','True')
     self.set_stdout_file('logs/' + exec_name + '-$(cluster)-$(process).out')
     self.set_stderr_file('logs/' + exec_name + '-$(cluster)-$(process).err')
@@ -3427,7 +3358,7 @@ class ExtendedCoincJob(InspiralAnalysisJob):
     exec_name = 'extended_background'
     sections = []
     extension = 'html'
-    InspiralAnalysisJob.__init__(self, cp, sections, exec_name, extension, dax=False)
+    InspiralAnalysisJob.__init__(self, cp, sections, exec_name, extension)
     self.add_condor_cmd('getenv','True')
 
 
