@@ -13,8 +13,8 @@
 *
 *  You should have received a copy of the GNU General Public License
 *  along with with program; see the file COPYING. If not, write to the
-*  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-*  MA  02111-1307  USA
+*  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+*  MA  02110-1301  USA
 */
 
 /*-----------------------------------------------------------------------
@@ -38,7 +38,7 @@
 #include <time.h>
 #include <math.h>
 
-#include <lalapps.h>
+#include <LALAppsVCSInfo.h>
 #include <series.h>
 #include <lalappsfrutils.h>
 
@@ -53,19 +53,17 @@
 #include <lal/LALFrStream.h>
 #include <lal/ResampleTimeSeries.h>
 #include <lal/Calibration.h>
-#include <lal/FrameCalibration.h>
 #include <lal/Window.h>
 #include <lal/TimeFreqFFT.h>
 #include <lal/IIRFilter.h>
 #include <lal/BandPassTimeSeries.h>
+#include <lal/LIGOLwXML.h>
+#include <lal/LIGOLwXMLRead.h>
 #include <lal/LIGOMetadataTables.h>
 #include <lal/LIGOMetadataUtils.h>
-#include <lal/LIGOLwXMLlegacy.h>
-#include <lal/LIGOLwXMLRead.h>
 #include <lal/Date.h>
 #include <lal/Units.h>
 #include <lal/FindChirp.h>
-#include <lal/LALFrameL.h>
 #include <lal/LALDict.h>
 #include <lal/LALNoiseModels.h>
 
@@ -129,7 +127,7 @@ REAL4 XLALCandleDistanceTD(
     UINT4 cut)
 {
 
-  LALStatus      status   = blank_status;
+  LALStatus      XLAL_INIT_DECL(status);
 
   InspiralTemplate  tmplt;
   REAL4Vector    *waveform = NULL;
@@ -187,30 +185,6 @@ REAL4 XLALCandleDistanceTD(
   return (REAL4)distance;
 }
 
-SummValueTable **add_summvalue_table(SummValueTable **newTable,
-    LIGOTimeGPS gpsStartTime, LIGOTimeGPS gpsEndTime,
-    const CHAR *programName, const CHAR *ifoName,
-    const CHAR *summValueName, const CHAR *comment, REAL8 value
-    )
-{
-  /* add value to summ_value table */
-  *newTable = (SummValueTable *) LALCalloc( 1, sizeof(SummValueTable) );
-  snprintf( (*newTable)->program, LIGOMETA_PROGRAM_MAX,
-      "%s", programName );
-  (*newTable)->version = 0;
-  (*newTable)->start_time = gpsStartTime;
-  (*newTable)->end_time = gpsEndTime;
-  snprintf( (*newTable)->ifo, LIGOMETA_IFO_MAX, "%s", ifoName );
-  snprintf( (*newTable)->name, LIGOMETA_SUMMVALUE_NAME_MAX,
-      "%s", summValueName );
-  snprintf( (*newTable)->comment, LIGOMETA_SUMMVALUE_COMM_MAX,
-      "%s", comment );
-  (*newTable)->value = value;
-
-  return (newTable);
-}
-
-
 
 void AddNumRelStrainModes(  LALStatus              *status,     /**< pointer to LALStatus structure */
                             REAL4TimeVectorSeries  **outStrain, /**< [out]  h+, hx data    */
@@ -435,25 +409,10 @@ void InjectNumRelWaveformsUsingPSDREAL8(LALStatus *status,         /**< pointer
 
 
   /* write and free the output simInspiral table */
-  if ( simTableOut ) {
-
-    LIGOLwXMLStream xmlfp;
-    MetadataTable dummyTable;
-    dummyTable.simInspiralTable = simTableOut;
-
-    /* write the xml table of actual injections */
-    if (fname) {
-      memset( &xmlfp, 0, sizeof(LIGOLwXMLStream) );
-      TRY( LALOpenLIGOLwXMLFile( status->statusPtr, &xmlfp, fname ), status );
-      TRY( LALBeginLIGOLwXMLTable( status->statusPtr, &xmlfp, sim_inspiral_table ),
-                status );
-
-      TRY( LALWriteLIGOLwXMLTable( status->statusPtr, &xmlfp, dummyTable,
-                                        sim_inspiral_table ), status );
-
-      TRY( LALEndLIGOLwXMLTable ( status->statusPtr, &xmlfp ), status );
-      TRY( LALCloseLIGOLwXMLFile ( status->statusPtr, &xmlfp ), status );
-    }
+  if ( simTableOut && fname ) {
+    LIGOLwXMLStream *xmlfp = XLALOpenLIGOLwXMLFile( fname );
+    XLALWriteLIGOLwXMLSimInspiralTable( xmlfp, simTableOut );
+    XLALCloseLIGOLwXMLFile( xmlfp );
   }
 
   while (simTableOut) {
@@ -547,21 +506,12 @@ void InjectNumRelWaveforms (LALStatus           *status,       /**< pointer to L
   /* write and free the output simInspiral table */
   if ( simTableOut ) {
 
-    LIGOLwXMLStream xmlfp;
-    MetadataTable dummyTable;
-      dummyTable.simInspiralTable = simTableOut;
+    LIGOLwXMLStream *xmlfp;
 
     /* write the xml table of actual injections */
-    memset( &xmlfp, 0, sizeof(LIGOLwXMLStream) );
-    TRY( LALOpenLIGOLwXMLFile( status->statusPtr, &xmlfp, fname ), status );
-    TRY( LALBeginLIGOLwXMLTable( status->statusPtr, &xmlfp, sim_inspiral_table ),
-              status );
-
-    TRY( LALWriteLIGOLwXMLTable( status->statusPtr, &xmlfp, dummyTable,
-                                      sim_inspiral_table ), status );
-
-    TRY( LALEndLIGOLwXMLTable ( status->statusPtr, &xmlfp ), status );
-    TRY( LALCloseLIGOLwXMLFile ( status->statusPtr, &xmlfp ), status );
+    xmlfp = XLALOpenLIGOLwXMLFile( fname );
+    XLALWriteLIGOLwXMLSimInspiralTable( xmlfp, simTableOut );
+    XLALCloseLIGOLwXMLFile( xmlfp );
 
   }
 
@@ -647,21 +597,12 @@ void InjectNumRelWaveformsREAL8 (LALStatus      *status,       /**< pointer to L
   /* write and free the output simInspiral table */
   if ( simTableOut ) {
 
-    LIGOLwXMLStream xmlfp;
-    MetadataTable dummyTable;
-    dummyTable.simInspiralTable = simTableOut;
+    LIGOLwXMLStream *xmlfp;
 
     /* write the xml table of actual injections */
-    memset( &xmlfp, 0, sizeof(LIGOLwXMLStream) );
-    TRY( LALOpenLIGOLwXMLFile( status->statusPtr, &xmlfp, fname ), status );
-    TRY( LALBeginLIGOLwXMLTable( status->statusPtr, &xmlfp, sim_inspiral_table ),
-              status );
-
-    TRY( LALWriteLIGOLwXMLTable( status->statusPtr, &xmlfp, dummyTable,
-                                      sim_inspiral_table ), status );
-
-    TRY( LALEndLIGOLwXMLTable ( status->statusPtr, &xmlfp ), status );
-    TRY( LALCloseLIGOLwXMLFile ( status->statusPtr, &xmlfp ), status );
+    xmlfp = XLALOpenLIGOLwXMLFile( fname );
+    XLALWriteLIGOLwXMLSimInspiralTable( xmlfp, simTableOut );
+    XLALCloseLIGOLwXMLFile( xmlfp );
 
   }
 
