@@ -13,8 +13,8 @@
 *
 *  You should have received a copy of the GNU General Public License
 *  along with with program; see the file COPYING. If not, write to the
-*  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-*  MA  02111-1307  USA
+*  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+*  MA  02110-1301  USA
 */
 
 /*-----------------------------------------------------------------------
@@ -37,7 +37,6 @@
 #include <regex.h>
 #include <time.h>
 
-#include <lalapps.h>
 #include <series.h>
 
 #include <lal/LALConfig.h>
@@ -47,10 +46,10 @@
 #include <lal/LALError.h>
 #include <lal/LALDatatypes.h>
 #include <lal/AVFactories.h>
+#include <lal/LIGOLwXML.h>
+#include <lal/LIGOLwXMLRead.h>
 #include <lal/LIGOMetadataTables.h>
 #include <lal/LIGOMetadataUtils.h>
-#include <lal/LIGOLwXMLlegacy.h>
-#include <lal/LIGOLwXMLRead.h>
 #include <lal/Units.h>
 #include <lal/Date.h>
 #include <lal/LALInspiral.h>
@@ -65,7 +64,7 @@
 #define CVS_DATE "$Date$"
 #define PROGRAM_NAME "tmpltbank"
 
-int arg_parse_check( int argc, char *argv[], MetadataTable procparams );
+int arg_parse_check( int argc, char *argv[], ProcessParamsTable *procparams );
 
 /*
  *
@@ -93,7 +92,7 @@ INT4                 outCompress = 0;
 int main ( int argc, char *argv[] )
 {
   /* lal function variables */
-  LALStatus             status = blank_status;
+  LALStatus             XLAL_INIT_DECL(status);
 
   /* templates */
   RandomParams         *randParams = NULL;
@@ -101,13 +100,10 @@ int main ( int argc, char *argv[] )
   SnglInspiralTable    *thisTmplt  = NULL;
 
   /* output data */
-  MetadataTable         templateBank;
-  MetadataTable         proctable;
-  MetadataTable         procparams;
-  MetadataTable         searchsummvars;
-  SearchSummvarsTable  *this_search_summvar = NULL;
-  ProcessParamsTable   *this_proc_param = NULL;
-  LIGOLwXMLStream       results;
+  SnglInspiralTable    *templateBank = NULL;
+  ProcessTable         *proctable;
+  ProcessParamsTable   *procparams;
+  LIGOLwXMLStream      *results;
 
   /* counters and other variables */
   INT4 i;
@@ -125,13 +121,12 @@ int main ( int argc, char *argv[] )
   lal_errhandler = LAL_ERR_EXIT;
 
   /* create the process and process params tables */
-  proctable.processTable = (ProcessTable *)
+  proctable = (ProcessTable *)
     calloc( 1, sizeof(ProcessTable) );
-  XLALGPSTimeNow(&(proctable.processTable->start_time));
-  XLALPopulateProcessTable(proctable.processTable, PROGRAM_NAME, lalAppsVCSIdentInfo.vcsId,
+  XLALGPSTimeNow(&(proctable->start_time));
+  XLALPopulateProcessTable(proctable, PROGRAM_NAME, lalAppsVCSIdentInfo.vcsId,
       lalAppsVCSIdentInfo.vcsStatus, lalAppsVCSIdentInfo.vcsDate, 0);
-  this_proc_param = procparams.processParamsTable = (ProcessParamsTable *)
-    calloc( 1, sizeof(ProcessParamsTable) );
+  procparams = (ProcessParamsTable *) calloc( 1, sizeof(ProcessParamsTable) );
 
   /* call the argument parse and check function */
   arg_parse_check( argc, argv, procparams );
@@ -146,12 +141,6 @@ int main ( int argc, char *argv[] )
    */
 
 
-  /* store the seed in the search summvars table */
-  this_search_summvar = searchsummvars.searchSummvarsTable =
-    (SearchSummvarsTable *) LALCalloc( 1, sizeof(SearchSummvarsTable) );
-  snprintf( this_search_summvar->name,
-      LIGOMETA_NAME_MAX, "template bank simulation seed" );
-
   if ( randSeedType == urandom )
   {
     FILE   *fpRand = NULL;
@@ -183,9 +172,6 @@ int main ( int argc, char *argv[] )
       fprintf( stdout, "using user specified random seed: " );
   }
 
-  this_search_summvar->value = randomSeed;
-  snprintf( this_search_summvar->string, LIGOMETA_STRING_MAX,
-      "%d", randomSeed );
   if ( vrbflg ) fprintf( stdout, "%d\n", randomSeed );
 
   /* create the tmplt bank random parameter structure */
@@ -200,9 +186,6 @@ int main ( int argc, char *argv[] )
    */
 
 
-  /* make sure the pointer to the first template is null */
-  templateBank.snglInspiralTable = NULL;
-
   for ( i = 0; i < numTmplts; ++i )
   {
     memset( &newTmplt, 0, sizeof(InspiralTemplate) );
@@ -231,9 +214,9 @@ int main ( int argc, char *argv[] )
 
     LAL_CALL( LALInspiralParameterCalc( &status, &newTmplt ), &status );
 
-    if ( ! templateBank.snglInspiralTable )
+    if ( ! templateBank )
     {
-      thisTmplt = templateBank.snglInspiralTable =
+      thisTmplt = templateBank =
         (SnglInspiralTable *) LALCalloc(1, sizeof(SnglInspiralTable));
     }
     else
@@ -270,7 +253,6 @@ int main ( int argc, char *argv[] )
    */
 
   /* open the output xml file */
-  memset( &results, 0, sizeof(LIGOLwXMLStream) );
   if ( userTag && !outCompress )
   {
     snprintf( fname, sizeof(fname), "P1-TMPLTBANK_%s-%d-%d.xml",
@@ -295,69 +277,37 @@ int main ( int argc, char *argv[] )
         gpsStartTime.gpsSeconds,
         gpsEndTime.gpsSeconds - gpsStartTime.gpsSeconds );
   }
-  LAL_CALL( LALOpenLIGOLwXMLFile( &status, &results, fname ), &status );
+  results = XLALOpenLIGOLwXMLFile( fname );
 
   /* write the process table */
-  snprintf( proctable.processTable->ifos, LIGOMETA_IFO_MAX, "P1" );
-  XLALGPSTimeNow(&(proctable.processTable->end_time));
-  LAL_CALL( LALBeginLIGOLwXMLTable( &status, &results, process_table ),
-      &status );
-  LAL_CALL( LALWriteLIGOLwXMLTable( &status, &results, proctable,
-        process_table ), &status );
-  LAL_CALL( LALEndLIGOLwXMLTable ( &status, &results ), &status );
-  free( proctable.processTable );
+  snprintf( proctable->ifos, LIGOMETA_IFO_MAX, "P1" );
+  XLALGPSTimeNow(&(proctable->end_time));
+  XLALWriteLIGOLwXMLProcessTable( results, proctable );
+  free( proctable );
 
   /* erase the first empty process params entry */
   {
-    ProcessParamsTable *emptyPPtable = procparams.processParamsTable;
-    procparams.processParamsTable = procparams.processParamsTable->next;
+    ProcessParamsTable *emptyPPtable = procparams;
+    procparams = procparams->next;
     free( emptyPPtable );
   }
 
   /* write the process params table */
-  LAL_CALL( LALBeginLIGOLwXMLTable( &status, &results, process_params_table ),
-      &status );
-  LAL_CALL( LALWriteLIGOLwXMLTable( &status, &results, procparams,
-        process_params_table ), &status );
-  LAL_CALL( LALEndLIGOLwXMLTable ( &status, &results ), &status );
-  while( procparams.processParamsTable )
-  {
-    this_proc_param = procparams.processParamsTable;
-    procparams.processParamsTable = this_proc_param->next;
-    free( this_proc_param );
-  }
-
-  /* write the search summvars table */
-  LAL_CALL( LALBeginLIGOLwXMLTable( &status, &results,
-        search_summvars_table ), &status );
-  LAL_CALL( LALWriteLIGOLwXMLTable( &status, &results, searchsummvars,
-        search_summvars_table ), &status );
-  LAL_CALL( LALEndLIGOLwXMLTable ( &status, &results ), &status );
-  while( searchsummvars.searchSummvarsTable )
-  {
-    this_search_summvar = searchsummvars.searchSummvarsTable;
-    searchsummvars.searchSummvarsTable = this_search_summvar->next;
-    LALFree( this_search_summvar );
-  }
+  XLALWriteLIGOLwXMLProcessParamsTable( results, procparams );
+  XLALDestroyProcessParamsTable( procparams );
 
   /* write the template bank to the file */
-  if ( templateBank.snglInspiralTable )
+  if ( templateBank )
+    XLALWriteLIGOLwXMLSnglInspiralTable( results, templateBank );
+  while ( templateBank )
   {
-    LAL_CALL( LALBeginLIGOLwXMLTable( &status, &results, sngl_inspiral_table ),
-        &status );
-    LAL_CALL( LALWriteLIGOLwXMLTable( &status, &results, templateBank,
-          sngl_inspiral_table ), &status );
-    LAL_CALL( LALEndLIGOLwXMLTable ( &status, &results ), &status );
-  }
-  while ( templateBank.snglInspiralTable )
-  {
-    thisTmplt = templateBank.snglInspiralTable;
-    templateBank.snglInspiralTable = templateBank.snglInspiralTable->next;
+    thisTmplt = templateBank;
+    templateBank = templateBank->next;
     LALFree( thisTmplt );
   }
 
   /* close the output xml file */
-  LAL_CALL( LALCloseLIGOLwXMLFile ( &status, &results ), &status );
+  XLALCloseLIGOLwXMLFile( results );
 
   /* free the rest of the memory, check for memory leaks and exit */
   LAL_CALL( LALDestroyRandomParams( &status, &randParams ), &status );
@@ -394,7 +344,7 @@ this_proc_param = this_proc_param->next = (ProcessParamsTable *) \
 "  --write-compress             write a compressed xml file\n"\
   "\n"
 
-int arg_parse_check( int argc, char *argv[], MetadataTable procparams )
+int arg_parse_check( int argc, char *argv[], ProcessParamsTable *procparams )
 {
   /* LALgetopt arguments */
   struct LALoption long_options[] =
@@ -415,7 +365,7 @@ int arg_parse_check( int argc, char *argv[], MetadataTable procparams )
     {0, 0, 0, 0}
   };
   int c;
-  ProcessParamsTable *this_proc_param = procparams.processParamsTable;
+  ProcessParamsTable *this_proc_param = procparams;
 
 
   /*
