@@ -37,17 +37,14 @@ import itertools
 from optparse import OptionParser
 import sys
 import tempfile
-try:
-    from configparser import ConfigParser
-except ImportError:  # python < 3
-    from ConfigParser import SafeConfigParser as ConfigParser
+from configparser import ConfigParser
 
 
 from ligo.segments import utils as segmentsUtils
 from glue import pipeline
 import lal
 from lal.utils import CacheEntry
-from lalapps import power
+from lalburst import power
 
 
 __author__ = "Kipp Cannon <kipp@gravity.phys.uwm.edu>"
