@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with with program; see the file COPYING. If not, write to the Free
- * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
- * 02111-1307  USA
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301  USA
  */
 
 
@@ -29,7 +29,8 @@
  */
 
 
-#include <lalapps.h>
+#include "config.h"
+
 #include <math.h>
 #include <stdarg.h>
 #include <stdio.h>
@@ -53,7 +54,6 @@
 #include <lal/LALStdlib.h>
 #include <lal/LIGOLwXML.h>
 #include <lal/LIGOLwXMLArray.h>
-#include <lal/LIGOLwXMLBurstRead.h>
 #include <lal/LIGOLwXMLRead.h>
 #include <lal/LIGOMetadataTables.h>
 #include <lal/LIGOMetadataUtils.h>
@@ -1094,7 +1094,7 @@ static struct injection_document *load_injection_document(const char *filename)
 
 	new->has_sim_burst_table = XLALLIGOLwHasTable(filename, "sim_burst");
 	if(new->has_sim_burst_table) {
-		new->sim_burst_table_head = XLALSimBurstTableFromLIGOLw(filename, NULL, NULL);
+		new->sim_burst_table_head = XLALSimBurstTableFromLIGOLw(filename);
 	} else
 		new->sim_burst_table_head = NULL;
 
