@@ -13,8 +13,8 @@
 *
 *  You should have received a copy of the GNU General Public License
 *  along with with program; see the file COPYING. If not, write to the
-*  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-*  MA  02111-1307  USA
+*  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+*  MA  02110-1301  USA
 */
 
 
@@ -29,7 +29,7 @@ void coh_PTF_template (
     )
 {
   UINT4 i;
-  LALStatus status = blank_status;
+  LALStatus XLAL_INIT_DECL(status);
   switch ( params->approximant )
   {
     /* Speacial case #1 */
