@@ -13,10 +13,12 @@
 *
 *  You should have received a copy of the GNU General Public License
 *  along with with program; see the file COPYING. If not, write to the
-*  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-*  MA  02111-1307  USA
+*  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+*  MA  02110-1301  USA
 */
 
+#include "config.h"
+
 #include <math.h>
 #include <string.h>
 
@@ -27,7 +29,7 @@
 #include <lal/TimeFreqFFT.h>
 #include <lal/Units.h>
 
-#include "lalapps.h"
+#include <LALAppsVCSInfo.h>
 #include "segment.h"
 #include "errutil.h"
 #include "gpstime.h"
