@@ -21,12 +21,12 @@ import sys
 
 
 from ligo import segments
-from glue import iterutils
 from glue import pipeline
+from lal import iterutils
 from lal import LIGOTimeGPS
 from lal.utils import CacheEntry
 from lalburst import cafe
-from lalapps import power
+from lalburst import power
 
 
 __author__ = 'Xavier Siemens<siemens@gravity.phys.uwm.edu>'
