@@ -25,10 +25,7 @@ from optparse import OptionParser
 import os
 import sys
 import tempfile
-try:
-	from configparser import ConfigParser
-except ImportError:  # python < 3
-	from ConfigParser import ConfigParser
+from configparser import ConfigParser
 
 
 from glue import pipeline
@@ -38,8 +35,8 @@ from ligo.lw.utils import segments as ligolw_segments
 from lal import LIGOTimeGPS
 from lal.utils import CacheEntry
 from lalburst import offsetvector
+from lalburst import power
 from lalapps import cosmicstring
-from lalapps import power
 from ligo import segments
 
 __author__ = 'Xavier Siemens<siemens@gravity.phys.uwm.edu>'
@@ -367,7 +364,7 @@ def make_coinc_branch(dag, datafinds, seglists, time_slides, min_segment_length,
 				lladd_nodes |= these_lladd_nodes
 
 		#
-		# lalapps_burca pool.  these are the burca jobs that don't
+		# lalburst_coinc pool.  these are the burca jobs that don't
 		# require special clipping command line options, and so can
 		# bulk-process many files with each job
 		#
@@ -379,7 +376,7 @@ def make_coinc_branch(dag, datafinds, seglists, time_slides, min_segment_length,
 			print("done %s %d/%d" % (tag, n + 1, len(time_slides)), file=sys.stderr)
 
 	#
-	# lalapps_binjfind
+	# lalburst_injfind
 	#
 
 	if do_injections:
@@ -388,7 +385,7 @@ def make_coinc_branch(dag, datafinds, seglists, time_slides, min_segment_length,
 		coinc_nodes = [power.make_binjfind_fragment(dag, these_coinc_nodes, "%s_%d" % (tag, n), verbose = verbose) for n, these_coinc_nodes in enumerate(coinc_nodes)]
 
 	#
-	# ligolw_sqlite and lalapps_run_sqlite
+	# ligolw_sqlite and ligolw_run_sqlite
 	#
 
 	if verbose:
