@@ -127,7 +127,7 @@ for n, filename in enumerate(filenames):
 		print("%d/%d: %s" % (n + 1, len(filenames), filename), file=sys.stderr)
 
 	working_filename = dbtables.get_connection_filename(filename, tmp_path = options.tmp_space, verbose = options.verbose)
-	connection = sqlite3.connect(working_filename)
+	connection = sqlite3.connect(str(working_filename))
 
 	#
 	# Define the is_vetoed() SQL function.
