@@ -34,12 +34,8 @@ from __future__ import print_function
 
 
 import bisect
-try:
-    import copyreg
-    import pickle
-except ImportError:  # python < 3
-    import copy_reg as copyreg
-    import cPickle as pickle
+import copyreg
+import pickle
 import heapq
 import itertools
 from optparse import OptionParser
@@ -792,7 +788,7 @@ def process_file(filename, products, live_time_program, tmp_path = None, veto_se
 	#
 
 	working_filename = dbtables.get_connection_filename(filename, tmp_path = tmp_path, verbose = verbose)
-	contents = SnglBurstUtils.CoincDatabase(sqlite3.connect(working_filename), live_time_program, search = "StringCusp", veto_segments_name = veto_segments_name)
+	contents = SnglBurstUtils.CoincDatabase(sqlite3.connect(str(working_filename)), live_time_program, search = "StringCusp", veto_segments_name = veto_segments_name)
 	if verbose:
 		SnglBurstUtils.summarize_coinc_database(contents, filename = working_filename)
 
@@ -807,7 +803,7 @@ def process_file(filename, products, live_time_program, tmp_path = None, veto_se
 
 	contents.filename = filename
 
-	contents.coincidence_segments = ligolwprocess.get_process_params(contents.xmldoc, "lalapps_burca", "--coincidence-segments")
+	contents.coincidence_segments = ligolwprocess.get_process_params(contents.xmldoc, "lalburst_coinc", "--coincidence-segments")
 	if contents.coincidence_segments:
 		# as a side-effect, this enforces the rule that
 		# burca has been run on the input file exactly once
