@@ -346,7 +346,7 @@ FROM
 		for instrument, data in sorted(self.dataA.items()):
 			fig, axes = SnglBurstUtils.make_burst_plot(r"SNR in %s" % instrument, r"$(f_{\mathrm{recovered}} - f_{\mathrm{injected}})/ f_{\mathrm{injected}}$")
 
-			axes.set_title("Cut-off Frequency Residual vs.\ SNR in %s\n(%d Found Injections)" % (instrument, data.found))
+			axes.set_title("Cut-off Frequency Residual vs.\\ SNR in %s\n(%d Found Injections)" % (instrument, data.found))
 			axes.loglog()
 			axes.plot(data.x, data.y, "k+")
 
@@ -432,7 +432,7 @@ FROM
 		for instrument, data in sorted(self.data.items()):
 			fig, axes = SnglBurstUtils.make_burst_plot(r"SNR", r"$\chi^{2} / \mathrm{DOF}$")
 
-			axes.set_title("$\chi^{2} / \mathrm{DOF}$ vs.\ SNR in %s" % instrument)
+			axes.set_title("$\\chi^{2} / \\mathrm{DOF}$ vs.\\ SNR in %s" % instrument)
 			axes.loglog()
 			axes.plot(data.injections_x, data.injections_y, "r+")
 			axes.plot(data.noninjections_x, data.noninjections_y, "k+")
@@ -483,7 +483,7 @@ for n, filename in enumerate(ligolw_utils.sort_files_by_size(filenames, options.
 	if options.verbose:
 		print("%d/%d: %s" % (n + 1, len(filenames), filename), file=sys.stderr)
 	working_filename = dbtables.get_connection_filename(filename, tmp_path = options.tmp_space, verbose = options.verbose)
-	database = SnglBurstUtils.CoincDatabase(sqlite3.connect(working_filename), options.live_time_program, search = "StringCusp")
+	database = SnglBurstUtils.CoincDatabase(sqlite3.connect(str(working_filename)), options.live_time_program, search = "StringCusp")
 	if options.verbose:
 		SnglBurstUtils.summarize_coinc_database(database)
 	is_injection_db = "sim_burst" in dbtables.get_table_names(database.connection)
